--Test Project for I2C
--Uses the I2C protocol to communicate with the Wolfson CODEC
--50KHz SCLK signal for I2C
--address of Wolfson is 0x34
--4/13/11

LIBRARY ieee;
USE ieee.std_logic_1164.all;

entity Neuron_Project is
	port(
		KEY: in std_logic_vector(3 downto 0);
		CLOCK_50: in std_logic;
		LEDG: out std_logic_vector (7 downto 0)
	);
end Neuron_Project;

architecture toplevel of Neuron_Project is

	--clock signal from the PLL clockBuffer
	signal clock50MHz: std_logic;
	--asynchronous reset for the whole project
	signal reset: std_logic;
	--50KHz clock signal for the I2C module
	signal clock50KHzI2C: std_logic;

	--PLL from MegaWizard in Quartus.
	--both input and output are 50MHz
	component clockBuffer IS
		PORT
		(
			areset		: IN STD_LOGIC  := '0';
			inclk0		: IN STD_LOGIC  := '0';
			c0		: OUT STD_LOGIC 
		);
	END component;
	
	--50KHz clock generator
	--with asynch active-high reset
	component clock50KHz is
		port(
			inClock,reset: in std_logic;
			outClock50KHz: out std_logic
		);
	end component;
	
begin

	--keys are active low
	reset <= not KEY(0);
	
	clockBufferInstance: clockBuffer port map(reset,CLOCK_50,clock50MHz);
	clock50KHzInstance: clock50KHz port map(clock50MHz,reset,clock50KHzI2C);
	
	--uses green LED as test output
	LEDG(7) <= clock50KHzI2C;

end toplevel;