--Test Project for the delayCounter
--waits for 40ms, then asserts active low reset output
--inputs are aysnchronous reset and 50MHz clock from clockBuffer
--4/13/11

--4/14/11
--Verified 40ms delay between reset low and assert high

LIBRARY ieee;
USE ieee.std_logic_1164.all;

entity Neuron_Project is
	port(
		KEY: in std_logic_vector(3 downto 0);
		CLOCK_50: in std_logic;
		--output for logic analyzer
		GPIO_0: out std_logic_vector (35 downto 0);
		LEDG: out std_logic_vector (7 downto 0)
	);
end Neuron_Project;

architecture toplevel of Neuron_Project is

	--clock signal from the PLL clockBuffer
	signal clock50MHz: std_logic;
	--asynchronous reset for the whole project
	signal reset: std_logic;
	--the active-high signal to the adcDacController
	signal AdcAssert: std_logic;

	--PLL from MegaWizard in Quartus.
	--both input and output are 50MHz
	component clockBuffer IS
		PORT
		(
			areset		: IN STD_LOGIC  := '0';
			inclk0		: IN STD_LOGIC  := '0';
			c0		: OUT STD_LOGIC 
		);
	END component;
	
	--delayCounter waits 40ms
	component delayCounter is
		port(
			clock,reset: in std_logic;
			resetAdc: out std_logic
		);
	end component;
	
begin

	--keys are active low
	reset <= not KEY(0);
	
	clockBufferInstance: clockBuffer port map(reset,CLOCK_50,clock50MHz);
	delayCounterInstance: delayCounter port map(clock50MHz,reset,AdcAssert);
	
	--uses green LED as test output
	--and logic analyzer
	GPIO_0(0) <= AdcAssert; --pin#16
	GPIO_0(1) <= reset;
	LEDG(7) <= AdcAssert;

end toplevel;