--4/15/11
--Test project for the I2C controller

LIBRARY ieee;
USE ieee.std_logic_1164.all;

entity Neuron_Project is
	port(
		KEY: in std_logic_vector(3 downto 0);
		CLOCK_50: in std_logic;
		I2C_SCLK: out std_logic;
		I2C_SDAT: inout std_logic;
		--output for logic analyzer
		GPIO_0: inout std_logic_vector (35 downto 0);
		LEDG: out std_logic_vector (7 downto 0)
	);
end Neuron_Project;

architecture toplevel of Neuron_Project is

	--for testing
	signal clock50KHz: std_logic;

	--clock signal from the PLL clockBuffer
	signal clock50MHz: std_logic;
	--asynchronous reset for the whole project
	signal reset: std_logic;
 
	--I2C data and clock lines
	signal i2cData, i2cClock: std_logic;
	
	--tri-state buffer control
	signal i2cDataControl: std_logic;
	signal i2cDataTriState: std_logic;

	--PLL from MegaWizard in Quartus.
	--both input and output are 50MHz
	component clockBuffer IS
		PORT
		(
			areset		: IN STD_LOGIC  := '0';
			inclk0		: IN STD_LOGIC  := '0';
			c0		: OUT STD_LOGIC 
		);
	END component;
	
	--I2C controller to drive the Wolfson codec
	component audioCodecController is
	port(
		clock50MHz,reset: in std_logic;
		I2C_SCLK_Internal: out std_logic;
		--must be inout to allow FPGA to read the ack bit
		I2C_SDAT_Internal: out std_logic;
		SDAT_Control: out std_logic;
		--for testing
		clock50KHz_Out: out std_logic
	);
	end component;
	
begin

	--keys are active low
	reset <= not KEY(0);
	
	clockBufferInstance: clockBuffer port map(reset,CLOCK_50,clock50MHz);
	I2CControllerInstance: audioCodecController port map(clock50MHz,reset,i2cClock,i2cData,i2cDataControl, clock50KHz);
	
	--tri-state data output
	i2cDataTriState <= i2cData when i2cDataControl = '1' else 'Z';
	--I2C output ports
	I2C_SCLK <= i2cClock;
	I2C_SDAT <= i2cDataTriState;
	
	--for testing
	GPIO_0(0) <= I2C_SDAT;
	GPIO_0(1) <= i2cClock;
	GPIO_0(2) <= clock50KHz;
	GPIO_0(3) <= i2cDataControl;
	GPIO_0(4) <= reset;
	
	LEDG(0) <= reset;

end toplevel;