--4/15/11
--ModelSim test bench for the I2C controller

LIBRARY ieee;
USE ieee.std_logic_1164.all;

entity audioCodecControllerTB is
end audioCodecControllerTB;

architecture testbench of audioCodecControllerTB is

	--ModelSim signals
	signal CLOCK_50: std_logic := '0';
	signal clockCount: integer := 0;
	signal I2C_SDAT: std_logic;
	signal I2C_SCLK: std_logic;
	signal clock50KHz: std_logic;
	
	--clock signal from the PLL clockBuffer
	signal clock50MHz: std_logic;
	--asynchronous reset for the whole project
	signal reset: std_logic := '1';

	--I2C data and clock lines
	signal i2cData, i2cClock: std_logic;

	--tri-state buffer control
	signal i2cDataControl: std_logic;
	
	--PLL from MegaWizard in Quartus.
	--both input and output are 50MHz
	component clockBuffer IS
		PORT
		(
			areset		: IN STD_LOGIC  := '0';
			inclk0		: IN STD_LOGIC  := '0';
			c0		: OUT STD_LOGIC 
		);
	END component;
	
	--I2C controller to drive the Wolfson codec
	component audioCodecController is
	port(
		clock50MHz,reset: in std_logic;
		I2C_SCLK_Internal: out std_logic;
		--must be inout to allow FPGA to read the ack bit
		I2C_SDAT_Internal: out std_logic;
		SDAT_Control: out std_logic;
		--for testing
		clock50KHz_Out: out std_logic
	);
	end component;
	
begin
	
	clockBufferInstance: clockBuffer port map(reset,CLOCK_50,clock50MHz);
	I2CControllerInstance: audioCodecController port map(clock50MHz,reset,i2cClock,i2cData,i2cDataControl, clock50KHz);
	
	--simulated output signals
	I2C_SDAT <= i2cData when i2cDataControl = '1' else 'Z';
	I2C_SCLK <= i2cClock; 
	
	--simulation stimulus
	clock: process
	begin
		--wait 1/2 clock cycle (50MHz clock)
		wait for 10 ns;
		CLOCK_50 <= not CLOCK_50;
	end process;

	clock_count: process(clock50MHz)
	begin
		if rising_edge(clock50MHz) then
			clockCount <= clockCount + 1;
		end if;
	end process;
	
	--temporary reset at start
	stimulus: process
	begin
		--active high reset
		reset <= '1';
		 --1 clock cycle
		wait for 20 ns;
		reset <= '0';
		--wait forever
		wait;
	end process;

end testbench;