LIBRARY ieee;
USE ieee.std_logic_1164.all;

entity clock50KHzTB is
end clock50KHzTB;

architecture testbench of clock50KHzTB is

	--test inputs
	signal KEY: std_logic_vector(3 downto 0) := "1111";
	signal CLOCK_50: std_logic := '1';
	--track the number of clock cycles from the PLL
	signal clockCount: integer := 0;

	--clock signal from the PLL clockBuffer
	signal clock50MHz: std_logic;
	--asynchronous reset for the whole project
	signal reset: std_logic;
	--50KHz clock signal for the I2C module
	signal clock50KHzI2C: std_logic;

	component clockBuffer IS
		PORT
		(
			areset		: IN STD_LOGIC  := '0';
			inclk0		: IN STD_LOGIC  := '0';
			c0		: OUT STD_LOGIC 
		);
	END component;
	
	--50KHz clock generator
	--with asynch active-high reset
	component clock50KHz is
		port(
			inClock,reset: in std_logic;
			outClock50KHz: out std_logic
		);
	end component;
	
begin

	--keys are active low
	reset <= not KEY(0);
	
	clockBufferInstance: clockBuffer port map(reset,CLOCK_50,clock50MHz);
	clock50KHzInstance: clock50KHz port map(clock50MHz,reset,clock50KHzI2C);
	
	--simulation stimulus
	clock: process
	begin
		--wait 1/2 clock cycle (50MHz clock)
		wait for 10 ns;
		CLOCK_50 <= not CLOCK_50;
	end process;

	--count the number of PLL clock cycles
	clock_count: process(clock50MHz)
	begin
		if rising_edge(clock50MHz) then
			clockCount <= clockCount + 1;
		end if;
	end process;
	
	--stimulus
	stimulus: process
	begin
		--start condition - in reset initially
		KEY(0) <= '0';
		wait for 20 ns; 
	
		--disable reset
		KEY(0) <= '1';

		--wait forever
		wait;
	end process;

end testbench;