--Test Project for the delayCounter
--waits for 40ms, then asserts active low reset output
--inputs are aysnchronous reset and 50MHz clock from clockBuffer
--4/13/11

LIBRARY ieee;
USE ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity delayCounterTB is
end delayCounterTB;

architecture testbench of delayCounterTB is

	--test inputs
	signal KEY: std_logic_vector(3 downto 0) := "1111";
	signal CLOCK_50: std_logic := '1';
	--track the number of clock cycles from the PLL
	signal clockCount: integer := 0;

	--clock signal from the PLL clockBuffer
	signal clock50MHz: std_logic;
	--asynchronous reset for the whole project
	signal reset: std_logic;
	--the active-high signal to the adcDacController
	signal AdcAssert: std_logic;

	--PLL from MegaWizard in Quartus.
	--both input and output are 50MHz
	component clockBuffer IS
		PORT
		(
			areset		: IN STD_LOGIC  := '0';
			inclk0		: IN STD_LOGIC  := '0';
			c0		: OUT STD_LOGIC 
		);
	END component;
	
	--delayCounter waits 40ms
	component delayCounter is
		port(
			clock,reset: in std_logic;
			resetAdc: out std_logic
		);
	end component;
	
begin

	--keys are active low
	reset <= not KEY(0);
	
	clockBufferInstance: clockBuffer port map(reset,CLOCK_50,clock50MHz);
	delayCounterInstance: delayCounter port map(clock50MHz,reset,AdcAssert);
	
	--simulation stimulus
	clock: process
	begin
		--wait 1/2 clock cycle (50MHz clock)
		wait for 10 ns;
		CLOCK_50 <= not CLOCK_50;
	end process;

	--should assert AdcAssert at 20,000 cycles (40ms)
	clock_count: process(clock50MHz)
	begin
		if rising_edge(clock50MHz) then
			clockCount <= clockCount + 1;
		end if;
	end process;
	
	--stimulus
	stimulus: process
	begin
		--start condition - in reset initially
		KEY(0) <= '0';
		wait for 20 ns; 
	
		--disable reset
		KEY(0) <= '1';

		--wait forever
		wait;
	end process;
	
end testbench;