--5/18/11
--ModelSim test bench for the neuron model and adcDacController

LIBRARY ieee;
USE ieee.std_logic_1164.all;

entity neuronModelTB is
end neuronModelTB;

architecture testbench of neuronModelTB is

	--generates digital audio interface clock signals
	--starts after delayCounter asserts (40ms)
	component AdcDacController is
		port(
			--reset signal starts '0', then goes to '1' after 40 ms => active-low
			resetn: in std_logic;
			--from 50MHz PLL at toplevel
			clock18MHz_in: in std_logic;
			--line-in on the DE1
			adcData: in std_logic;
			--line-out on the DE1
			dacData: out std_logic;
			bitClock: out std_logic;
			dacLRSelect: out std_logic;
			adcLRSelect: out std_logic;
			--neuron model signals
			neuronVin: in std_logic_vector(15 downto 0);
			neuronUin: in std_logic_vector(15 downto 0);
			--selects loopback or neuron signals using switches
			outputSelect: in std_logic_vector(1 downto 0)
		);
	end component;
	
	--generates the neuron model signals using euler's method
	component neuronModel is
		port(
			frameClock: in std_logic;
			resetn: in std_logic;
			vOut: out std_logic_vector(17 downto 0);
			uOut: out std_logic_vector(17 downto 0)
		);
	end component;
	
	--18MHz PLL output signal
	signal clock18MHz: std_logic := '0';
	
	--assert signal from delay counter
	signal codecResetn: std_logic;
	
	--audio codec signals
	signal adcDat_sig: std_logic := '1';
	signal adcLRCK_sig: std_logic;
	signal dacLRCK_sig: std_logic;
	signal dacDat_sig: std_logic;
	signal bck_sig: std_logic;
	
	--neuron model signals
	signal vNeuronSig: std_logic_vector(17 downto 0);
	signal uNeuronSig: std_logic_vector(17 downto 0);
	signal outputSelect: std_logic_vector(1 downto 0);

begin

	--Codec Controller
	AdcDacControllerMap: AdcDacController port map(codecResetn, clock18MHz, adcDat_sig, dacDat_sig,
		bck_sig, dacLRCK_sig, adcLRCK_sig, vNeuronSig(17 downto 2), uNeuronSig(17 downto 2), outputSelect);
		
	--neuron model
	neuronModelMap: neuronModel port map(adcLRCK_sig, codecResetn, vNeuronSig, uNeuronSig);
	
	process
	begin
		--wait 1/2 clock cycle (~18MHz clock)
		wait for 28 ns;
		clock18MHz <= not clock18MHz;
	end process;
	
	--temporary reset at start
	process
	begin
		--active high reset
		codecResetn <= '0';
		--don't care about this
		adcDat_sig <= '1';
		--read neuron outputs
		outputSelect <= "01";
		--1 clock cycle
		wait for 20 ns;
		codecResetn <= '1';
		--wait forever
		wait;
	end process;

end testbench;